"""
A package of support modules to ease the task of writing Konversation scripts
in Python.

This package is considered EXPERIMENTAL at this time and not part of the
public, stable scripting interface.

Modules:
dbus -- Interact with Konveration's D-Bus API.
i18n -- Translation support.

"""
